@@ -86,7 +86,7 @@ class Client:
     RequestsInterval = 1
 
     MinClientVersion = 142
-    MaxClientVersion = 152
+    MaxClientVersion = 163
 
     (DISCONNECTED, CONNECTING, CONNECTED) = range(3)
 
@@ -121,6 +121,7 @@ class Client:
         self._apiReady = False
         self._serverVersion = None
         self._data = b''
+        self._hasReqId = False
         self._reqIdSeq = 0
         self._accounts = []
         self._startTime = time.time()
@@ -204,8 +205,8 @@ class Client:
             self._logger.info(
                 f'Connecting to {host}:{port} with clientId {clientId}...')
             self.host = host
-            self.port = port
-            self.clientId = clientId
+            self.port = int(port)
+            self.clientId = int(clientId)
             self.connState = Client.CONNECTING
             timeout = timeout or None
             await asyncio.wait_for(self.conn.connectAsync(host, port), timeout)
@@ -216,7 +217,7 @@ class Client:
             self.conn.sendMsg(msg)
             await asyncio.wait_for(self.apiStart, timeout)
             self._logger.info('API connection ready')
-        except Exception as e:
+        except BaseException as e:
             self.disconnect()
             msg = f'API connection failed: {e!r}'
             self._logger.error(msg)
@@ -342,11 +343,12 @@ class Client:
                     msgId = int(fields[0])
                     if msgId == 9:
                         _, _, validId = fields
-                        self._reqIdSeq = int(validId)
+                        self.updateReqId(int(validId))
+                        self._hasReqId = True
                     elif msgId == 15:
                         _, _, accts = fields
                         self._accounts = [a for a in accts.split(',') if a]
-                    if self._reqIdSeq and self._accounts:
+                    if self._hasReqId and self._accounts:
                         self._apiReady = True
                         self.apiStart.emit()
 
@@ -595,7 +597,12 @@ class Client:
             fields += [order.discretionaryUpToLimitPrice]
         if version >= 151:
             fields += [order.usePriceMgmtAlgo]
-
+        if version >= 158:
+            fields += [order.duration]
+        if version >= 160:
+            fields += [order.postToAts]
+        if version >= 162:
+            fields += [order.autoCancelParent]
         self.send(*fields)
 
     def cancelOrder(self, orderId):
@@ -675,8 +682,11 @@ class Client:
     def requestFA(self, faData):
         self.send(18, 1, faData)
 
-    def replaceFA(self, faData, cxml):
-        self.send(19, 1, faData, cxml)
+    def replaceFA(self, reqId, faData, cxml):
+        fields = [19, 1, faData, cxml]
+        if self.serverVersion() >= 157:
+            fields += [reqId]
+        self.send(*fields)
 
     def reqHistoricalData(
             self, reqId, contract, endDateTime, durationStr, barSizeSetting,
