@@ -9,7 +9,8 @@ from typing import (
     Any, Dict, List, Optional, Set, Tuple, Union, cast)
 
 from ib_insync.contract import (
-    Contract, ContractDescription, ContractDetails, ScanData)
+    Contract, ContractDescription, ContractDetails, DeltaNeutralContract,
+    ScanData)
 from ib_insync.objects import (
     AccountValue, BarData, BarDataList, CommissionReport,
     DOMLevel, DepthMktDataDescription,
@@ -338,7 +339,8 @@ class Wrapper:
         """
         if order.whatIf:
             # response to whatIfOrder
-            self._endReq(order.orderId, orderState)
+            if orderState.commissionCurrency:
+                self._endReq(order.orderId, orderState)
         else:
             key = self.orderKey(order.clientId, order.orderId, order.permId)
             trade = self.trades.get(key)
@@ -521,7 +523,7 @@ class Wrapper:
 
     def realtimeBar(
             self, reqId: int, time: int, open_: float, high: float, low: float,
-            close: float, volume: int, wap: float, count: int):
+            close: float, volume: float, wap: float, count: int):
         dt = datetime.fromtimestamp(time, timezone.utc)
         bar = RealTimeBar(dt, -1, open_, high, low, close, volume, wap, count)
         bars = self.reqId2Subscriber.get(reqId)
@@ -590,7 +592,7 @@ class Wrapper:
 
     # additional wrapper method provided by Client
     def priceSizeTick(
-            self, reqId: int, tickType: int, price: float, size: int):
+            self, reqId: int, tickType: int, price: float, size: float):
         ticker = self.reqId2Ticker.get(reqId)
         if not ticker:
             self._logger.error(f'priceSizeTick: Unknown reqId: {reqId}')
@@ -657,7 +659,7 @@ class Wrapper:
         ticker.marketDataType = self.reqId2MarketDataType.get(reqId, 0)
         self.pendingTickers.add(ticker)
 
-    def tickSize(self, reqId: int, tickType: int, size: int):
+    def tickSize(self, reqId: int, tickType: int, size: float):
         ticker = self.reqId2Ticker.get(reqId)
         if not ticker:
             self._logger.error(f'tickSize: Unknown reqId: {reqId}')
@@ -716,7 +718,7 @@ class Wrapper:
 
     def tickByTickAllLast(
             self, reqId: int, tickType: int, time: int, price: float,
-            size: int, tickAttribLast: TickAttribLast,
+            size: float, tickAttribLast: TickAttribLast,
             exchange, specialConditions):
         ticker = self.reqId2Ticker.get(reqId)
         if not ticker:
@@ -736,7 +738,8 @@ class Wrapper:
 
     def tickByTickBidAsk(
             self, reqId: int, time: int, bidPrice: float, askPrice: float,
-            bidSize: int, askSize: int, tickAttribBidAsk: TickAttribBidAsk):
+            bidSize: float, askSize: float,
+            tickAttribBidAsk: TickAttribBidAsk):
         ticker = self.reqId2Ticker.get(reqId)
         if not ticker:
             self._logger.error(f'tickByTickBidAsk: Unknown reqId: {reqId}')
@@ -792,9 +795,9 @@ class Wrapper:
                 priceStr, sizeStr, rtTime, volume, vwap, _ = value.split(';')
                 if volume:
                     if tickType == 48:
-                        ticker.rtVolume = int(volume)
+                        ticker.rtVolume = float(volume)
                     elif tickType == 77:
-                        ticker.rtTradeVolume = int(volume)
+                        ticker.rtTradeVolume = float(volume)
                 if vwap:
                     ticker.vwap = float(vwap)
                 if rtTime:
@@ -803,7 +806,7 @@ class Wrapper:
                 if priceStr == '':
                     return
                 price = float(priceStr)
-                size = int(sizeStr)
+                size = float(sizeStr)
                 if price and size:
                     if ticker.prevLast != ticker.last:
                         ticker.prevLast = ticker.last
@@ -869,13 +872,13 @@ class Wrapper:
 
     def updateMktDepth(
             self, reqId: int, position: int, operation: int, side: int,
-            price: float, size: int):
+            price: float, size: float):
         self.updateMktDepthL2(
             reqId, position, '', operation, side, price, size)
 
     def updateMktDepthL2(
             self, reqId: int, position: int, marketMaker: str, operation: int,
-            side: int, price: float, size: int, isSmartDepth: bool = False):
+            side: int, price: float, size: float, isSmartDepth: bool = False):
         # operation: 0 = insert, 1 = update, 2 = delete
         # side: 0 = ask, 1 = bid
         ticker = self.reqId2Ticker[reqId]
@@ -897,11 +900,11 @@ class Wrapper:
         self.pendingTickers.add(ticker)
 
     def tickOptionComputation(
-            self, reqId: int, tickType: int, impliedVol: float, delta: float,
-            optPrice: float, pvDividend: float, gamma: float, vega: float,
-            theta: float, undPrice: float):
+            self, reqId: int, tickType: int, tickAttrib: int,
+            impliedVol: float, delta: float, optPrice: float, pvDividend:
+            float, gamma: float, vega: float, theta: float, undPrice: float):
         comp = OptionComputation(
-            impliedVol, delta, optPrice, pvDividend,
+            tickAttrib, impliedVol, delta, optPrice, pvDividend,
             gamma, vega, theta, undPrice)
         ticker = self.reqId2Ticker.get(reqId)
         if ticker:
@@ -923,6 +926,9 @@ class Wrapper:
             self._logger.error(
                 f'tickOptionComputation: Unknown reqId: {reqId}')
 
+    def deltaNeutralValidation(self, reqId: int, dnc: DeltaNeutralContract):
+        pass
+
     def fundamentalData(self, reqId: int, data: str):
         self._endReq(reqId, data)
 
@@ -1048,7 +1054,8 @@ class Wrapper:
                 trade = self.trades[(self.clientId, reqId)]
                 if not trade.isDone():
                     status = trade.orderStatus.status = OrderStatus.Cancelled
-                    logEntry = TradeLogEntry(self.lastTime, status, msg)
+                    logEntry = TradeLogEntry(
+                        self.lastTime, status, msg, errorCode)
                     trade.log.append(logEntry)
                     self._logger.warning(f'Canceled order: {trade}')
                     self.ib.orderStatusEvent.emit(trade)
